# copyright Stanford Exploration Project.  See GNU public license.
#
# This file is part of SEP's set of GNU make rules for electronic documents
# This file contains rules for building, burning, and inspecting result files
#
${SEPINC}/Doc.rules.red: ; 

# For dummy targets #
.PHONY : FORCE
FORCE: ; 

### BUILD ###

# make sure result files are never removed as intermediates
non_int = ${addprefix ${RESDIR}/, ${RESULTSALL}}
.PRECIOUS : ${foreach sf, ${RES_SUFFIXES},${addsuffix ${sf},${non_int}}}

# different build targets of various ease of reproducibility: take your pick
# "make buildER" makes all easily reproducible results (listed in RESULTSER)
buildER   : ${addsuffix .build, ${RESULTSER}}
buildCR   : ${addsuffix .build, ${RESULTSCR}}
buildall  : ${addsuffix .build, ${RESULTSREP}}
build     : buildER

# SEP convention: the user gurantees that all result files are created
# when creating the target ${RESDIR}/%.ps (often the result file is a 
# postscript figure: therefore the naming convention). 
%.build : ${RESDIR}/%.ps 
	@	# gmake seems to need a non-empty command-body

### BURN ###

# different burn targets of various ease of reproducibility
# "make burnER" burns all easily reproducible results (listed in RESULTSER)
burnER  : ${addsuffix .burn, ${RESULTSER}}
burnCR  : ${addsuffix .burn, ${RESULTSCR}}
burnall : ${addsuffix .burn, ${RESULTSREP}}
burn    : burnER

# SEP convention: all result files are identified by being in ${RESDIR}
# and having a result suffix as specified in ${RES_SUFFIXES}. Any existing
# result file corresponding to a the stem in %.burn is removed.
%.burn : FORCE
	@-\
	  ${foreach sfx, ${RES_SUFFIXES} ,		\
	    if ${EXIST} ${RESDIR}/$*${sfx} ; then	\
	         ${RM}  ${RESDIR}/$*${sfx} ;  fi;	\
	  }

### VIEW ###

# 2 commands to display a result file. Before displaying 
# view up-dates the result file, obube only checks existence 
view  : ${addsuffix  .view, ${RESULTSALL}}

# displays the format of the result file which is most enjoyable for 
# screen display
%.view: FORCE
	@\
	if   ${CANDO_GIF}    ; then	\
	  ${MAKE} $*.viewgif ;		\
	elif ${CANDO_PS}     ; then	\
	  ${MAKE} $*.viewps  ;		\
	else				\
          echo "make $@: cannot make targets $*.% (% = viewps, viewgif)" ; \
	fi

SHOW_GIF = ${XVIEW} ${OXVIEWFLAGS} ${UXVIEWFLAGS} ${RESDIR}/$*.gif
SHOW_PS  = ${GVIEW} ${OGVIEWFLAGS} ${UGVIEWFLAGS} ${RESDIR}/$*.ps

%.viewgif  : ${RESDIR}/%.gif FORCE
	${SHOW_GIF}

%.viewps : ${RESDIR}/%.ps FORCE
	${SHOW_PS}

### CLEAN ###

.PHONY : jclean klean.usual klean.tex klean.fort 

# SEP's GNU make rules do not supply a general clean rule, since such
# a rule easily removes the wrong files. The rules in this file are 
# based on some simple naming (especially suffix!) conventions. An author
# uses these rules by making a jclean a dependency to his target clean.
jclean : klean.usual klean.tex klean.fort ;

# To keep the clean rules silent (i.e. to suppress warnings from gmake
# arising from rm returning a non-zero value), we touch some files into
# existence.
# Note that e.g. a ps file in the local directory is considered an 
# intermediate file and is removed. However a ps file in ${RESDIR} is 
# considered a result file and is not removed.
KLEANUSUAL := core a.out paper.log *.o *.x *.H *.ps *.gif 
klean.usual :
	@-${TOUCH} ${KLEANUSUAL} junk.quiet
	@-${RM}    ${KLEANUSUAL} junk.*

KLEANTEX   :=  *.dvi *.aux *.bbl *.blg *.log *.toc TEX[0-9]*
klean.tex :
	@-${TOUCH} ${KLEANTEX}  junk.aux
	@-${RM}    ${KLEANTEX}  junk.*

FORT_FILES = $(patsubst %.f,%,$(wildcard *.f)) junk.quiet
klean.fort:
	@\
	for name in ${FORT_FILES} ; do				\
	  if  ${EXIST} $${name}.r ; then 			\
	      ${TOUCH} $${name}.f ;				\
	      ${RM}    $${name}.f ;				\
	  fi ;							\
	done
